From: tip-bot for Thomas Gleixner <tglx@linutronix.de>
To: linux-tip-commits@vger.kernel.org
Cc: linux-kernel@vger.kernel.org, hpa@zytor.com, mingo@redhat.com,
jbarnes@virtuousgeek.org, jacob.jun.pan@intel.com,
tglx@linutronix.de
Subject: [tip:x86/mrst] x86, pci: Add arch_init to x86_init abstraction
Date: Fri, 26 Feb 2010 04:45:42 GMT [thread overview]
Message-ID: <tip-4fb6088a5cb3a77123fea1279bf2d5b16cf27648@git.kernel.org> (raw)
In-Reply-To: <43F901BD926A4E43B106BF17856F0755A318CE84@orsmsx508.amr.corp.intel.com>
Commit-ID: 4fb6088a5cb3a77123fea1279bf2d5b16cf27648
Gitweb: http://git.kernel.org/tip/4fb6088a5cb3a77123fea1279bf2d5b16cf27648
Author: Thomas Gleixner <tglx@linutronix.de>
AuthorDate: Mon, 22 Feb 2010 05:38:38 -0800
Committer: H. Peter Anvin <hpa@zytor.com>
CommitDate: Thu, 25 Feb 2010 19:24:43 -0800
x86, pci: Add arch_init to x86_init abstraction
Added an abstraction function for arch specific init calls.
Signed-off-by: Jacob Pan <jacob.jun.pan@intel.com>
Cc: Jesse Barnes <jbarnes@virtuousgeek.org>
LKML-Reference: <43F901BD926A4E43B106BF17856F0755A318CE84@orsmsx508.amr.corp.intel.com>
Signed-off-by: H. Peter Anvin <hpa@zytor.com>
---
arch/x86/include/asm/x86_init.h | 8 +++++---
1 files changed, 5 insertions(+), 3 deletions(-)
diff --git a/arch/x86/include/asm/x86_init.h b/arch/x86/include/asm/x86_init.h
index 8ef56f2..b1d62bb 100644
--- a/arch/x86/include/asm/x86_init.h
+++ b/arch/x86/include/asm/x86_init.h
@@ -98,13 +98,15 @@ struct x86_init_iommu {
int (*iommu_init)(void);
};
/*
* struct x86_init_pci - platform specific pci init functions
* @init: platform specific pci init
* @init_irq: platform specific pci irq init
* @fixup_irqs: platform specific pci irq fixup
*/
struct x86_init_pci {
+ int (*arch_init)(void);
int (*init)(void);
void (*init_irq)(void);
void (*fixup_irqs)(void);
parent reply other threads:[~2010-02-26 4:46 UTC|newest]
Thread overview: expand[flat|nested] mbox.gz Atom feed
[parent not found: <43F901BD926A4E43B106BF17856F0755A318CE84@orsmsx508.amr.corp.intel.com>]
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tip-4fb6088a5cb3a77123fea1279bf2d5b16cf27648@git.kernel.org \
--to=tglx@linutronix.de \
--cc=hpa@zytor.com \
--cc=jacob.jun.pan@intel.com \
--cc=jbarnes@virtuousgeek.org \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-tip-commits@vger.kernel.org \
--cc=mingo@redhat.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -98,13 +98,15 @@ struct x86_init_iommu {
int (*iommu_init)(void);
};
- /*
- * struct x86_init_pci - platform specific pci init functions
- * @init: platform specific pci init
+/**
+ * struct x86_init_pci - platform specific pci init functions
+ * @arch_init: platform specific pci arch init call
+ * @init: platform specific pci subsystem init
* @init_irq: platform specific pci irq init
* @fixup_irqs: platform specific pci irq fixup
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox